@@ -24,25 +24,25 @@ public:
 
     static FilterAction *newAction();
 
-    Q_REQUIRED_RESULT QString displayString() const override;
+    [[nodiscard]] QString displayString() const override;
 
-    Q_REQUIRED_RESULT QString argsAsString() const override;
+    [[nodiscard]] QString argsAsString() const override;
     void argsFromString(const QString &argsStr) override;
 
-    Q_REQUIRED_RESULT SearchRule::RequiredPart requiredPart() const override;
-    Q_REQUIRED_RESULT FilterAction::ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
+    [[nodiscard]] SearchRule::RequiredPart requiredPart() const override;
+    [[nodiscard]] FilterAction::ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
 
-    Q_REQUIRED_RESULT bool isEmpty() const override;
+    [[nodiscard]] bool isEmpty() const override;
 
-    Q_REQUIRED_RESULT QString informationAboutNotValidAction() const override;
+    [[nodiscard]] QString informationAboutNotValidAction() const override;
 
-    Q_REQUIRED_RESULT QWidget *createParamWidget(QWidget *parent) const override;
+    [[nodiscard]] QWidget *createParamWidget(QWidget *parent) const override;
     void setParamWidgetValue(QWidget *paramWidget) const override;
     void applyParamWidgetValue(QWidget *paramWidget) override;
 
-    Q_REQUIRED_RESULT GpgME::Key key() const;
+    [[nodiscard]] GpgME::Key key() const;
 
-    Q_REQUIRED_RESULT bool reencrypt() const;
+    [[nodiscard]] bool reencrypt() const;
 
 private:
     std::shared_ptr<const Kleo::KeyCache> mKeyCache;
