@@ -1,19 +1,7 @@
 /*
- * Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
+ * SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
@@ -21,9 +9,10 @@
 
 #include "filter/dialog/filteractionmissingsoundurldialog.h"
 
+#include <phonon/mediaobject.h>
 
 #include <KLocalizedString>
-#include <QMediaPlayer>
+
 #include <QFile>
 #include <QPointer>
 
@@ -31,7 +20,6 @@ using namespace MailCommon;
 
 FilterActionPlaySound::FilterActionPlaySound()
     : FilterActionWithTest(QStringLiteral("play sound"), i18n("Play Sound"))
-    , mPlayer(nullptr)
 {
 }
 
@@ -56,11 +44,10 @@ FilterAction::ReturnCode FilterActionPlaySound::process(ItemContext &, bool) con
         return ErrorButGoOn;
     }
     if (!mPlayer) {
-        mPlayer = new QMediaPlayer;
+        mPlayer = Phonon::createPlayer(Phonon::NotificationCategory);
     }
 
-    mPlayer->setMedia(QUrl::fromLocalFile(mParameter));
-    mPlayer->setVolume(50);
+    mPlayer->setCurrentSource(mParameter);
     mPlayer->play();
     return GoOn;
 }
@@ -89,3 +76,5 @@ QString FilterActionPlaySound::informationAboutNotValidAction() const
 {
     return i18n("Sound file was not defined.");
 }
+
+#include "moc_filteractionplaysound.cpp"
